@@ -4,10 +4,11 @@
 Demonstrates the use of the Drawing block.
 
 No hardware required.
+Requires the cv2 module to be installed.
 """
 
 from time import sleep
-
+from pkg_resources import resource_filename
 import crappy
 
 
@@ -28,26 +29,26 @@ class TestBlock(crappy.Block):
     sleep(.2)
 
 
-img = "data/Pad.png"
-
-coord = [  # Coordinates for the thermocouples
-         (185, 430),  # T1
-         (145, 320),  # T2
-         (105, 220),  # T3
-         (720, 370),  # T4
-         (720, 250),  # T5
-         (720, 125),  # T6
-         (1220, 410),  # T7
-         (1260, 320),  # T8
-         (1300, 230),  # T9
-         ]
-
-options = [{'type': 'dot_text',
-            'coord': coord[i],
-            'text': 'T{} = %.1f'.format(i + 1),
-            'label': 'T' + str(i + 1)} for i in range(9)]
-
 if __name__ == "__main__":
+  img = crappy.resources.paths['pad']
+
+  coord = [  # Coordinates for the thermocouples
+    (185, 430),  # T1
+    (145, 320),  # T2
+    (105, 220),  # T3
+    (720, 370),  # T4
+    (720, 250),  # T5
+    (720, 125),  # T6
+    (1220, 410),  # T7
+    (1260, 320),  # T8
+    (1300, 230),  # T9
+  ]
+
+  options = [{'type': 'dot_text',
+              'coord': coord[i],
+              'text': 'T{} = %.1f'.format(i + 1),
+              'label': 'T' + str(i + 1)} for i in range(9)]
+
   s = TestBlock([d['label'] for d in options])
 
   options.append({"type": 'time', 'coord': (80, 1000)})
