@@ -14,8 +14,10 @@ chan = [0, 2, 3, 4, 5]
 
 if __name__ == "__main__":
   m = crappy.blocks.IOBlock("Labjack_t7",
-      channels=[dict(name='AIN%d' % i, thermocouple='K') for i in chan],
-      verbose=True, labels=['t(s)'] + ['T%d' % i for i in chan])
+                            channels=[dict(name='AIN%d' % i, thermocouple='K')
+                                      for i in chan],
+                            verbose=True, labels=['t(s)'] + ['T%d' % i
+                                                             for i in chan])
 
   g = crappy.blocks.Grapher(*[('t(s)', 'T%d' % i) for i in chan])
 
